@@ -1,6 +1,6 @@
 var searchData=
 [
   ['hik_5fcamera_2eh_0',['hik_camera.h',['../da/d35/camera_2hik__camera_8h.html',1,'(全局命名空间)'],['../d3/d41/ara_2camera_2hik__camera_8h.html',1,'(全局命名空间)']]],
-  ['hik_5flight_5fcontrol_2eh_1',['hik_light_control.h',['../d8/da6/hik__light__control_8h.html',1,'']]],
+  ['hik_5flight_5fcontrol_2eh_1',['hik_light_control.h',['../d9/db9/light_2hik__light__control_8h.html',1,'(全局命名空间)'],['../d0/df1/ara_2light_2hik__light__control_8h.html',1,'(全局命名空间)']]],
   ['how_5fto_5fuse_2emd_2',['how_to_use.md',['../da/d31/combo_2how__to__use_8md.html',1,'(全局命名空间)'],['../d9/de1/compensator_2how__to__use_8md.html',1,'(全局命名空间)'],['../d0/d8b/decider_2how__to__use_8md.html',1,'(全局命名空间)'],['../d1/d58/detector_2how__to__use_8md.html',1,'(全局命名空间)'],['../d1/d43/feature_2how__to__use_8md.html',1,'(全局命名空间)'],['../dd/d50/group_2how__to__use_8md.html',1,'(全局命名空间)'],['../d2/db3/predictor_2how__to__use_8md.html',1,'(全局命名空间)'],['../de/df8/tracker_2how__to__use_8md.html',1,'(全局命名空间)']]]
 ];
