@@ -2,5 +2,6 @@ var searchData=
 [
   ['cmake_20使用_20rmvl_0',['通过 gcc 和 CMake 使用 RMVL',['../da/d80/tutorial_use.html',1,'tutorial_table_of_content_config']]],
   ['combo_20模块_1',['如何使用/开发 combo 模块',['../d2/d3f/tutorial_extra_how_to_use_combo.html',1,'tutorial_table_of_content_extra']]],
-  ['compensator_20模块_2',['如何使用/开发 compensator 模块',['../d9/de9/tutorial_extra_how_to_use_compensator.html',1,'tutorial_table_of_content_extra']]]
+  ['compensator_20模块_2',['如何使用/开发 compensator 模块',['../d9/de9/tutorial_extra_how_to_use_compensator.html',1,'tutorial_table_of_content_extra']]],
+  ['core_20模块_3',['适用于 Python 的 core 模块',['../d7/d9d/tutorial_py_core.html',1,'tutorial_py_table_of_contents_modules']]]
 ];
